/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 2.0
 */

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// This enumeration describes the values that the various error dispositions can be. The enumeration will be used
    /// by the bread crumb trail tag to determine how to handle any exceptions that occur. Exceptions can be ignored,
    /// can be rendered or can be thrown
    /// </summary>
    /// <remarks>
    /// This enumeration can be specified by the user in either the tags or control of the IDE. The silent errors is
    /// then set in the bread control trail tag and stored in the view state of the control. The enumeration is then
    /// used in the rendering process of the bread crumb trail control to determine what an exceptions disposition is.
    /// </remarks>
    public enum ErrorDisposition : int
    {
        /// <summary>
        /// This enumeration constant represents all errors being ignored silently. In other words - if an exception
        /// occurs, it will be ignored and the process will continue.
        /// </summary>
        /// <value>
        /// 0
        /// </value>
        SilentlyIgnore = 0,
        /// <summary>
        /// This enumeration constant represents the exception that occurs will be written to the output stream (HTML
        /// writer).
        /// </summary>
        /// <value>
        /// 1
        /// </value>
        RenderException = 1,
        /// <summary>
        /// This enumeration constant represents the first exception encountered will be immediately rethrown to the
        /// IIS engine.
        /// </summary>
        /// <value>
        /// 2
        /// </value>
        ThrowException = 2
    }
}
