/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 2.0
 */

using System;
using System.Web.UI;

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// This interface defines the contract for classes wishing to discover the path from current node to the root
    /// node. Implementations of this interface will be called with the current node and the current page context. The
    /// implementation is then suppose to discover the complete path from the current node to the root or return null
    /// when it can't discover the current path.
    /// </summary>
    /// <remarks>
    /// Implementations of this class will be created in the <see cref="BreadCrumbTrailControl.RenderContents"/> method
    /// via the object factory. The class will be created in <see cref="BreadCrumbTrailControl.RenderContents"/> when
    /// the path should be discovered. The returned path, if any, will then be used to format the html (i.e. each node
    /// will be passed to the <see cref="IPathWriter"/> for formatting with path separators in between).
    /// Implementations should be thread safe in the context of the rendering process.
    /// </remarks>
    public interface IPathDiscovery
    {
        /// <summary>
        /// This method should return the path from the current node for the given page context. The current node can
        /// have a null title if the current node should default to that found in the data source for this
        /// implementation. The returned nodes, however, should have a title assigned to each node.
        /// </summary>
        /// <remarks>
        /// The node URLs can include query strings on both the current node that is called and in those that are
        /// returned in the path. Implementers of this method should return an array where the 0th index position is
        /// the 'root' node and the nth-1 index position is the current node, or null if the current path could not be
        /// determined.
        /// </remarks>
        /// <param name="currentNode">A non-null node representing the current page.</param>
        /// <param name="page">The non-null page context.</param>
        /// <exception cref="ArgumentNullException">If <paramref name="currentNode"/> has a null URL or
        /// <paramref name="page"/> is null.</exception>
        /// <exception cref="BreadCrumbException">For any exception while discovering the path.</exception>
        /// <returns>A <see cref="BreadCrumbNode"/> array describing a path from root to current node.</returns>
        BreadCrumbNode[] GetPath(BreadCrumbNode currentNode, Page page);
    }
}
