/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER
 * Version: 2.0
 */

using NUnit.Framework;
using NUnit.Extensions.Asp;
using System;
using System.IO;
using System.Threading;

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// This class is a base for separate classes targeted at testing the functionality in the real IIS ASP.NET host.
    /// </summary>
    [TestFixture]
    public abstract class HttpTest : WebFormTestCase
    {
        /// <summary>
        /// Sets up the test fixture. This includes copying the needed DLLs, while avoiding the test assembly itself,
        /// as that will result in double definitions of several classes. These files are intentionally left behind to
        /// make it easy to run manual tests, like the demo.
        /// </summary>
        [TestFixtureSetUp]
        public virtual void SetupFixture()
        {
            try
            {
                Directory.CreateDirectory(@"..\..\test_files\bin\");
            }
            catch (Exception)
            {
            }

            File.Copy(@"..\..\build\classes\TopCoder.Web.UI.WebControl.BreadCrumb.dll",
                    @"..\..\test_files\bin\TopCoder.Web.UI.WebControl.BreadCrumb.dll", true);


            // Our dependencies should already always be current, if they exist
            // We avoid some locking problems by minimzing the number of copy operations
            if (!File.Exists(@"..\..\test_files\bin\TopCoder.Util.ConfigurationManager.dll"))
            {
                File.Copy(@"..\..\build\classes\TopCoder.Util.ConfigurationManager.dll",
                        @"..\..\test_files\bin\TopCoder.Util.ConfigurationManager.dll", true);
            }

            if (!File.Exists(@"..\..\test_files\bin\TopCoder.Util.ObjectFactory.dll"))
            {
                File.Copy(@"..\..\build\classes\TopCoder.Util.ObjectFactory.dll",
                          @"..\..\test_files\bin\TopCoder.Util.ObjectFactory.dll", true);
            }


            bool succeeded = false;

            while (!succeeded)
            {
                // File locking may stop us from doing this... Delay.
                try
                {
                    // Get absolute paths for our testing root
                    foreach (string path in Directory.GetFiles(@"..\..\test_files", "*.template"))
                    {
                        // This will work if the path doesn't contain any special characters
                        using (StreamReader reader = File.OpenText(path))
                        {
                            string content = reader.ReadToEnd();
                            content = string.Format(content, new DirectoryInfo(@"..\..\test_files").FullName);
                            // Strip off the final extension
                            using (StreamWriter writer = File.CreateText(path.Substring(0, path.IndexOf(".template"))))
                            {
                                writer.WriteLine(content);
                            }
                        }
                    }
                    succeeded = true;
                }
                catch (Exception)
                {
                }

                if (succeeded)
                {
                    break;
                }
                Thread.Sleep(5000);
            }
        }

        /// <summary>
        /// Strips out the string of the returned text (surrounded by $START$/$END$), and verifies the contents.
        /// </summary>
        /// <param name="text">The text to verify.</param>
        public void VerifyString(string text)
        {
            string pageText = Browser.CurrentPageText;
            int startIndex = pageText.IndexOf("$START$") + "$START$".Length;
            int endIndex = pageText.IndexOf("$END$") - startIndex;
            pageText = pageText.Substring(startIndex, endIndex);

            NUnit.Framework.Assert.AreEqual(text, pageText, "Text doesn't match.");
        }
    }
}
