/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER
 * Version: 2.0
 */

using NUnit.Framework;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery
{
    /// <summary>
    /// This class tests the dynamic path discovery class.
    /// </summary>
    [TestFixture]
    public class HttpTestDynamicPathDiscovery : HttpTest
    {
        /// <summary>
        /// We move around between different pages, how we get to a specific child SHOULD affect the trail.
        /// </summary>
        /// <remarks>
        /// We keep this in a single test case to create the desired trail. The fact that the URLs in the static map
        /// do NOT match the real URLs used also illustrates some effects.
        /// </remarks>
        [Test]
        public void TestWandering()
        {
            Browser.GetPage(@"http://localhost/Dyn.aspx?unknown");
            VerifyString(@"<span id=""bcc""><a href=""/Dyn.aspx?=unknown"">Unknown</a></span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?main");
            VerifyString(@"<span id=""bcc""><a href=""/Dyn.aspx?=main"">Main</a></span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?child1");
            VerifyString(@"<span id=""bcc""><a href=""/Dyn.aspx?=main"">Main</a><span>:</span>" +
                @"<a href=""/Dyn.aspx?=child1"">Child1</a>" +
                @"</span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?childFolder");
            VerifyString(@"<span id=""bcc""><a href=""/Dyn.aspx?=main"">Main</a><span>:</span>" +
                @"<a href=""/Dyn.aspx?=child1"">Child1</a><span>:</span><a href=""/Dyn.aspx?=childFolder"">" +
                @"ChildFolder</a></span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?child3");
            VerifyString(@"<span id=""bcc""><a href=""/Dyn.aspx?=main"">Main</a><span>:</span>" +
                @"<a href=""/Dyn.aspx?=child1"">Child1</a><span>:</span><a href=""/Dyn.aspx?=childFolder"">" +
                @"ChildFolder</a><span>:</span><a href=""/Dyn.aspx?=child3"">Child3</a></span>");

            // Go to a page which doesn't exist, it's appened dynamically
            Browser.GetPage(@"http://localhost/Dyn.aspx?child5");
            VerifyString(@"<span id=""bcc""><a href=""/Dyn.aspx?=main"">Main</a><span>:</span>" +
                @"<a href=""/Dyn.aspx?=child1"">Child1</a><span>:</span><a href=""/Dyn.aspx?=childFolder"">" +
                @"ChildFolder</a><span>:</span><a href=""/Dyn.aspx?=child3"">Child3</a>" +
                @"<span>:</span><a href=""/Dyn.aspx?=child5"">Unknown</a></span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?child4");
            VerifyString(@"<span id=""bcc""><a href=""/Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/childFolder/"">ChildFolder</a><span>:</span>" +
                @"<a href=""/Dyn.aspx?=child4"">Child4</a></span>");

            // Go up along the existing path
            Browser.GetPage(@"http://localhost/Dyn.aspx?childFolder");
            VerifyString(@"<span id=""bcc""><a href=""/Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/Dyn.aspx?=childFolder"">ChildFolder</a></span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?child4");
            VerifyString(@"<span id=""bcc""><a href=""/Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/Dyn.aspx?=childFolder"">ChildFolder</a><span>:</span>" +
                @"<a href=""/Dyn.aspx?=child4"">Child4</a></span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?child2");
            VerifyString(@"<span id=""bcc""><a href=""/"">Main</a><span>:</span><a href=""/Dyn.aspx?=child2"">" +
                @"Child2</a></span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?other");
            VerifyString(@"<span id=""bcc""><a href=""/Dyn.aspx?=other"">Alternative root</a></span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?childFolder");
            VerifyString(@"<span id=""bcc""><a href=""/Dyn.aspx?=other"">Alternative root</a><span>:</span>" +
                @"<a href=""/Dyn.aspx?=childFolder"">ChildFolder</a></span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?Other");
            VerifyString(@"<span id=""bcc""><a href=""/Dyn.aspx?=Other"">Alternative root2</a></span>");

            Browser.GetPage(@"http://localhost/Dyn.aspx?childFolder");
            VerifyString(@"<span id=""bcc""><a href=""/Dyn.aspx?=Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/Dyn.aspx?=childFolder"">ChildFolder</a></span>");

            // Drill down to a completely different node again
            Browser.GetPage(@"http://localhost/Dyn.aspx?child2");
            VerifyString(@"<span id=""bcc""><a href=""/"">Main</a><span>:</span><a href=""/Dyn.aspx?=child2"">" +
                @"Child2</a></span>");
        }
    }
}
