/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER
 * Version: 2.0
 */

using NUnit.Framework;
using System;

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// This class tests <see cref="BreadCrumbException"/>. These tests are somewhat simplistic, as is the tested class
    /// itself.
    /// </summary>
    [TestFixture]
    public class TestBreadCrumbException
    {
        /// <summary>
        /// Tests the message constructor.
        /// </summary>
        [Test]
        public void TestMessageConstructor()
        {
            Exception e = new BreadCrumbException("message");
            Assert.AreEqual("message", e.Message, "The message is as expected.");
            Assert.IsNull(e.InnerException, "The inner exception should be null.");
        }

        /// <summary>
        /// Tests the message constructor with a null message, which is allowed.
        /// </summary>
        [Test]
        public void TestMessageNull()
        {
            new BreadCrumbException(null);
        }

        /// <summary>
        /// Tests the two-param constructor.
        /// </summary>
        [Test]
        public void TestDualConstructor()
        {
            Exception inner = new Exception();
            Exception e = new BreadCrumbException("message", inner);
            Assert.AreEqual("message", e.Message, "The message is as expected.");
            Assert.AreEqual(inner, e.InnerException, "The inner exception doesn't match.");
        }

        /// <summary>
        /// Tests the two-param constructor, with deserialization in between.
        /// </summary>
        [Test]
        public void TestDualConstructorSerialize()
        {
            Exception inner = new Exception("msg2");
            Exception e = (Exception) Helper.DeSerialize(new BreadCrumbException("message", inner));
            Assert.AreEqual("message", e.Message, "The message is as expected.");
            Assert.AreEqual(inner.Message, e.InnerException.Message, "The inner exception doesn't match.");
        }

        /// <summary>
        /// Tests the two-param constructor with a null message, which is allowed.
        /// </summary>
        [Test]
        public void TestDualMessageNull()
        {
            new BreadCrumbException(null, new Exception());
        }

        /// <summary>
        /// Tests the two-param constructor with a null inner exception.
        /// </summary>
        [Test]
        public void TestDualInnerNull()
        {
            new BreadCrumbException("message", null);
        }
    }
}
