/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER
 * Version: 2.0
 */

using System;
using NUnit.Framework;

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// This class tests the struct <see cref="BreadCrumbNode"/>, a simple storage for the title and URL string.
    /// </summary>
    [TestFixture]
    public class TestBreadCrumbNode
    {
        /// <summary>
        /// A test object array.
        /// </summary>
        private BreadCrumbNode[] testObjects = new BreadCrumbNode[2];

        /// <summary>
        /// Sets up the test objects, one through deserialization.
        /// </summary>
        [SetUp]
        public void Setup()
        {
            testObjects[0] = new BreadCrumbNode("title", "url");
            testObjects[1] = (BreadCrumbNode) Helper.DeSerialize(testObjects[0]);
        }

        /// <summary>
        /// Tests the URL readonly property, verifying the value.
        /// </summary>
        [Test]
        public void TestUrl()
        {
            foreach (BreadCrumbNode node in testObjects)
            {
                Assert.AreEqual("url", node.Url, "Url should match.");
            }
        }

        /// <summary>
        /// Tests the title readonly property, verifying the value.
        /// </summary>
        [Test]
        public void TestTitle()
        {
            foreach (BreadCrumbNode node in testObjects)
            {
                Assert.AreEqual("title", node.Title, "Title should match.");
            }
        }

        /// <summary>
        /// Tests constructing with a null title, which is allowed.
        /// </summary>
        [Test]
        public void TestNullTitle()
        {
            Assert.IsNull(new BreadCrumbNode(null, "url").Title, "A null title is null.");
        }

        /// <summary>
        /// Tests constructing with an empty title, which is allowed, but also is converted to null.
        /// </summary>
        [Test]
        public void TestEmptyTitle()
        {
            Assert.IsNull(new BreadCrumbNode(" ", "url").Title, "An empty title is null.");
        }

        /// <summary>
        /// Tests constructing with a null URL, which is not allowed, an exception is thrown.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestNullUrl()
        {
            new BreadCrumbNode("title", null);
        }

        /// <summary>
        /// Tests constructing with an empty URL, which is not allowed, an exception is thrown.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentException))]
        public void TestEmptyUrl()
        {
            new BreadCrumbNode("title", " ");
        }
    }
}
